AdaTokenType

Enum AdaTokenType 

pub enum AdaTokenType {
Show 116 variants Whitespace, Newline, Comment, StringLiteral, CharacterLiteral, NumberLiteral, Identifier, Abort, Abs, Abstract, Accept, Access, Aliased, All, And, Array, At, Begin, Body, Case, Constant, Declare, Delay, Delta, Digits, Do, Else, Elsif, End, Entry, Exception, Exit, For, Function, Generic, Goto, If, In, Interface, Is, Limited, Loop, Mod, New, Not, Null, Of, Or, Others, Out, Overriding, Package, Pragma, Private, Procedure, Protected, Raise, Range, Record, Rem, Renames, Requeue, Return, Reverse, Select, Separate, Some, Subtype, Synchronized, Tagged, Task, Terminate, Then, Type, Until, Use, When, While, With, Xor, Plus, Minus, Star, Slash, Ampersand, Eq, Ne, Lt, Le, Gt, Ge, Assign, ColonEq, Arrow, Dot, DotDot, Comma, Colon, Semicolon, Bar, Pipe, Apostrophe, Tick, LeftParen, RightParen, Box, DoubleStar, StarStar, LtLt, GtGt, LeftBracket, RightBracket, LeftBrace, RightBrace, Eof, Error,
}
Ada 词法分析器的词法单元类型。

Variants



Whitespace

空白字符。



Newline

换行符。



Comment

注释。



StringLiteral

字符串字面量。



CharacterLiteral

字符字面量。



NumberLiteral

数字字面量。



Identifier

标识符。



Abort

abort 关键字。



Abs

abs 关键字。



Abstract

abstract 关键字。



Accept

accept 关键字。



Access

access 关键字。



Aliased

aliased 关键字。



All

all 关键字。



And

and 关键字。



Array

array 关键字。



At

at 关键字。



Begin

begin 关键字。



Body

body 关键字。



Case

case 关键字。



Constant

constant 关键字。



Declare

declare 关键字。



Delay

delay 关键字。



Delta

delta 关键字。



Digits

digits 关键字。



Do

do 关键字。



Else

else 关键字。



Elsif

elsif 关键字。



End

end 关键字。



Entry

entry 关键字。



Exception

exception 关键字。



Exit

exit 关键字。



For

for 关键字。



Function

function 关键字。



Generic

generic 关键字。



Goto

goto 关键字。



If

if 关键字。



In

in 关键字。



Interface

interface 关键字。



Is

is 关键字。



Limited

limited 关键字。



Loop

loop 关键字。



Mod

mod 关键字。



New

new 关键字。



Not

not 关键字。



Null

null 关键字。



Of

of 关键字。



Or

or 关键字。



Others

others 关键字。



Out

out 关键字。



Overriding

overriding 关键字。



Package

package 关键字。



Pragma

pragma 关键字。



Private

private 关键字。



Procedure

procedure 关键字。



Protected

protected 关键字。



Raise

raise 关键字。



Range

range 关键字。



Record

record 关键字。



Rem

rem 关键字。



Renames

renames 关键字。



Requeue

requeue 关键字。



Return

return 关键字。



Reverse

reverse 关键字。



Select

select 关键字。



Separate

separate 关键字。



Some

some 关键字。



Subtype

subtype 关键字。



Synchronized

synchronized 关键字。



Tagged

tagged 关键字。



Task

task 关键字。



Terminate

terminate 关键字。



Then

then 关键字。



Type

type 关键字。



Until

until 关键字。



Use

use 关键字。



When

when 关键字。



While

while 关键字。



With

with 关键字。



Xor

xor 关键字。



Plus

加号 (+)。



Minus

减号 (-)。



Star

乘号 (*)。



Slash

除号 (/)。



Ampersand

连接符 (&)。



Eq

等于 (=)。



Ne

不等于 (/=)。



Lt

小于 (<)。



Le

小于等于 (<=)。



Gt

大于 (>)。



Ge

大于等于 (>=)。



Assign

赋值 (:=)。



ColonEq

赋值别名 (:=)。



Arrow

箭头 (=>)。



Dot

点 (.)。



DotDot

范围 (..)。



Comma

逗号 (,)。



Colon

冒号 (:)。



Semicolon

分号 (;)。



Bar

竖线 (|)。



Pipe

竖线别名 (|)。



Apostrophe

撇号 (')。



Tick

撇号别名 (')。



LeftParen

左括号 (()。



RightParen

右括号 ())。



Box

框号 (<>)。



DoubleStar

幂运算 (**)。



StarStar

幂运算别名 (**)。



LtLt

左标签分隔符 (<<)。



GtGt

右标签分隔符 (>>)。



LeftBracket

左方括号 ([)。



RightBracket

右方括号 (])。



LeftBrace

左花括号 ({)。



RightBrace

右花括号 (})。



Eof

流结束。



Error

错误标记。

Implementations

Source

impl AdaTokenType

pub fn is_keyword(&self) -> bool

是否为关键字

pub fn is_identifier(&self) -> bool

是否为标识符

pub fn is_literal(&self) -> bool

是否为字面量